@@ -1,22 +1,10 @@
 from __future__ import annotations
 
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Dict,
-    Mapping,
-    MutableMapping,
-    Optional,
-    Sequence,
-    Tuple,
-    Type,
-    Union,
-    cast,
-)
+from typing import TYPE_CHECKING, cast, overload
 
 import aiohttp
 
-from .abc import KitBase
+from .base import KitBase
 from .data import (
     Alliance,
     Color,
@@ -31,6 +19,20 @@ from .data import (
 from .errors import GraphQLError
 from .paginator import AlliancePaginator, NationPaginator, Paginator
 
+if TYPE_CHECKING:
+    from typing import (
+        Any,
+        Dict,
+        Literal,
+        Mapping,
+        MutableMapping,
+        Optional,
+        Sequence,
+        Tuple,
+        Type,
+        Union,
+    )
+
 
 class AsyncKit(KitBase):
     async def _query(
@@ -45,7 +47,7 @@ class AsyncKit(KitBase):
         async with aiohttp.request(
             "GET", self.graphql_url(), json={"query": query}
         ) as response:
-            data: dict = await response.json()
+            data: Any = await response.json()
             try:
                 if "errors" in data[0]:
                     error = (
@@ -95,6 +97,28 @@ class AsyncKit(KitBase):
         data = tuple(type_(i) for i in response["data"][endpoint])
         return data
 
+    @overload
+    async def alliance_query(
+        self,
+        params: MutableMapping[str, Any],
+        arg: Union[str, Mapping[str, Any]],
+        *args: Union[str, Mapping[str, Any]],
+        paginator: Literal[False] = False,
+        **kwargs: Any,
+    ) -> Tuple[Alliance, ...]:
+        ...
+
+    @overload
+    async def alliance_query(
+        self,
+        params: MutableMapping[str, Any],
+        arg: Union[str, Mapping[str, Any]],
+        *args: Union[str, Mapping[str, Any]],
+        paginator: Literal[True] = True,
+        **kwargs: Any,
+    ) -> AlliancePaginator:
+        ...
+
     async def alliance_query(
         self,
         params: MutableMapping[str, Any],
@@ -140,6 +164,28 @@ class AsyncKit(KitBase):
             data = cast(Tuple[Color, ...], data)
         return data
 
+    @overload
+    async def nation_query(
+        self,
+        params: MutableMapping[str, Any],
+        arg: Union[str, Mapping[str, Any]],
+        *args: Union[str, Mapping[str, Any]],
+        paginator: Literal[False] = False,
+        **kwargs: Any,
+    ) -> Tuple[Nation, ...]:
+        ...
+
+    @overload
+    async def nation_query(
+        self,
+        params: MutableMapping[str, Any],
+        arg: Union[str, Mapping[str, Any]],
+        *args: Union[str, Mapping[str, Any]],
+        paginator: Literal[True] = True,
+        **kwargs: Any,
+    ) -> NationPaginator:
+        ...
+
     async def nation_query(
         self,
         params: MutableMapping[str, Any],
